@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Type, Union
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -40,7 +40,7 @@ __all__ = ("EBSClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -59,7 +59,7 @@ class Exceptions:
 
 class EBSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
     """
 
@@ -75,7 +75,7 @@ class EBSClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can_paginate)
         """
 
@@ -92,21 +92,21 @@ class EBSClient(BaseClient):
         Seals and completes the snapshot after all of the required blocks of data have
         been written to it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.complete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete_snapshot)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate_presigned_url)
         """
 
@@ -116,7 +116,7 @@ class EBSClient(BaseClient):
         """
         Returns the data in a block in an Amazon Elastic Block Store snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.get_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get_snapshot_block)
         """
 
@@ -133,7 +133,7 @@ class EBSClient(BaseClient):
         Returns information about the blocks that are different between two Amazon
         Elastic Block Store snapshots of the same volume/snapshot lineage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.list_changed_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_changed_blocks)
         """
 
@@ -148,7 +148,7 @@ class EBSClient(BaseClient):
         """
         Returns information about the blocks in an Amazon Elastic Block Store snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_snapshot_blocks)
         """
 
@@ -166,7 +166,7 @@ class EBSClient(BaseClient):
         """
         Writes a block of data to a snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.put_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put_snapshot_block)
         """
 
@@ -175,7 +175,7 @@ class EBSClient(BaseClient):
         *,
         VolumeSize: int,
         ParentSnapshotId: str = None,
-        Tags: List["TagTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         Description: str = None,
         ClientToken: str = None,
         Encrypted: bool = None,
@@ -185,6 +185,6 @@ class EBSClient(BaseClient):
         """
         Creates a new Amazon EBS snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.start_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start_snapshot)
         """
